core Package — mio 0.1.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- mio 0.1.8 documentation »
- API Documentation »

# core Package

## `core` Package

class `mio.core.` `Core`

  Bases: `mio.object.Object`

  `load_objects`()
  `create_objects`()

## `block` Module

`mio.core.block.` `getargname`(arg)

class `mio.core.block.` `Call`(value=<class 'mio.utils.Null'>, methods=True)

  Bases: `mio.object.Object`

  Call Object

class `mio.core.block.` `Locals`(value=<class 'mio.utils.Null'>, methods=True)

  Bases: `mio.object.Object`

  Locals Object

  `args`(receiver, context, m, name)

class `mio.core.block.` `Block`(body=None, args=None, kwargs=None, scope=None)

  Bases: `mio.object.Object`

  `create_locals`(receiver, context, m)
  `get_args`(receiver, context, m)
  `get_kwargs`(receiver, context, m)
  `get_body`(receiver, context, m)

## `continuation` Module

class `mio.core.continuation.` `Continuation`

  Bases: `mio.object.Object`

  `current`(receiver, context, m)

## `error` Module

class `mio.core.error.` `Error`

  Bases: `mio.object.Object`

  `init`(receiver, context, m, type=None, message=None)
  `call`(receiver, context, m, message=None)

## `exception` Module

class `mio.core.exception.` `Exception`(value=<class 'mio.utils.Null'>, methods=True)

  Bases: `mio.object.Object`

  `tryEval`(receiver, context, m, code)
  `raiseError`(receiver, context, m, error)

## `ffi` Module

`mio.core.ffi.` `create_module`(name, code)

`mio.core.ffi.` `wrap_function`(f)

class `mio.core.ffi.` `FFI`

  Bases: `mio.object.Object`

  `create_attributes`()
  `init`(receiver, context, m, name, code)
  `fromfile`(receiver, context, m, filename)

## `file` Module

class `mio.core.file.` `File`(value=<class 'mio.utils.Null'>, methods=True)

  Bases: `mio.object.Object`

  `update_status`()
  `close`(receiver, context, m)
  `flush`(receiver, context, m)
  `open`(receiver, context, m, filename, mode=None)
  `read`(receiver, context, m, size=None)
  `readline`(receiver, context, m)
  `readlines`(receiver, context, m)
  `seek`(receiver, context, m, offset, whence=None)
  `pos`(receiver, context, m)
  `truncate`(receiver, context, m, size=None)
  `write`(receiver, context, m, data)
  `writelines`(receiver, context, m, data)

## `generator` Module

class `mio.core.generator.` `Generator`

  Bases: `mio.object.Object`

  `init`(receiver, context, m)
  `setNextMessage`(receiver, context, m, message)
  `getNext`(receiver, context, m)

## `importer` Module

class `mio.core.importer.` `Importer`

  Bases: `mio.object.Object`

  `build_paths`()
  `find_match`(name, current=None)

## `message` Module

class `mio.core.message.` `Message`(name=None, value=None, args=None)

  Bases: `mio.object.Object`

  `eval`(receiver, context=None, m=None, target=None)
  `init`(receiver, context, m)
  `evalIn`(receiver, context, m, target=None)
  `evalArg`(receiver, context, m, index, target=None)
  `getArgs`(receiver, context, m)
  `evalArgs`(receiver, context, m, target=None)
  `getFirst`(receiver, context, m)
  `getName`(receiver, context, m)
  `getNext`(receiver, context, m)
  `getLast`(receiver, context, m)
  `getPrevious`(receiver, context, m)
  `setArgs`(receiver, context, m, *args)
  `setName`(receiver, context, m, name)
  `setNext`(receiver, context, m, message)
  `args`
  `first`
  `next`
  `last`
  `previous`

## `module` Module

class `mio.core.module.` `Module`

  Bases: `mio.object.Object`

  `init`(receiver, context, m, name, file)

## `parser` Module

class `mio.core.parser.` `Parser`(value=<class 'mio.utils.Null'>, methods=True)

  Bases: `mio.object.Object`

  `parse`(receiver, context, m, code)

## `path` Module

`mio.core.path.` `listdir`(path, fil=None, rec=False)

class `mio.core.path.` `Path`(path=None, expanduser=False)

  Bases: `mio.object.Object`

  `init`(receiver, context, m, path=None, expanduser=False)
  `join`(receiver, context, m, *args)
  `open`(receiver, context, m, mode='r')
  `list`(receiver, context, m, fil=None, rec=False)

## `range` Module

class `mio.core.range.` `Range`

  Bases: `mio.object.Object`

  `init`(receiver, context, m, *args)
  `setStep`(receiver, context, m, value)
  `getItem`(receiver, context, m, i)
  `mio__len__`(receiver, context, m)

## `state` Module

class `mio.core.state.` `State`

  Bases: `mio.object.Object`

  `reset`()
  `stop`
  `setContinue`(receiver, context, m, value=None)
  `setReturn`(receiver, context, m, value=None)
  `setBreak`(receiver, context, m, value=None)

## `system` Module

class `mio.core.system.` `System`

  Bases: `mio.object.Object`

  `build_args`()
  `exit`(receiver, context, m, status=None)

### Navigation

- index
- modules |
- next |
- previous |
- mio 0.1.8 documentation »
- API Documentation »